  % Induction motor line starting
  % Effect of rotor resistance or inertia on transient characteristics
 
 function IMstartrotoreffect
 clc,clear,close all
 global L p Rr J
 info= ...
        ['                       INDUCTION MOTOR LINE STARTING                             '                                
         '                  (Effect of rotor resistance or inertia)                        '
         ' The motor is starting at no load and, after reaching steady-state speed, a step '   
         ' load torque is suddenly applied. A choice of parametric run mode is offered.    '  
         ' The dynamic equations are expressed in canonical first-order matrix form        ' 
         ' adopting fluxes and speed as state variables, and are solved using ODE45.       '
         ' The machine parameters may be changed by editing the file <IMstartrotoreffect.m>' 
         ' The torque, speed,and current responses are plotted.                            '];
     disp(info)
k=0 ;
co='rbg';
% ---------------------------  ODE  ---------------------------------------
%%%%%%%  SELECT MODE OF PARAMETRIC RUN (Rr or J) %%%%%%%%%%%%%%%%%
   %for Rr=[.2 .35 .6];s1='Effect of rotor resistance'; % Rr [ohm]
     Rr=0.35;

 for J=[.05 .1 .15];s1='Effect of rotor inertia';   % J [kg.m^2]
       % J=0.1; 
       
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    k=k+1;
 xo = zeros(6,1) ;      %initial conditions 
 tf=2 ;                 % final time
 tspan=[0 tf] ; 
 options=odeset('RelTol',1e-3,'maxstep',1e-3); 
 [t,x]=ode45(@IMstf,tspan,xo,options);
 % --------------------  OUTPUT VARIABLES  --------------------------------
 flux=x(:,1:4)'  ;
 cur=L\flux ;
 spd=x(:,5)*60/(p*pi);  %rpm
 phids=x(:,1); phiqs=x(:,2);
 ids=cur(1,:)' ;   iqs=cur(2,:)' ;
 Te=0.75*p*(iqs.*phids-ids.*phiqs);
 is=sqrt(ids.*ids+iqs.*iqs);
  warning ('off')
% --------------------  GRAPHICAL DISPLAYS  -------------------------------
  figure('Units','Normalized','Position',[.02 .53 .5 .35],'Name','Induction motor starting transients');
    figure(1)
    plot(t,spd,co(k));title(s1,'color','b','fontweight','bold');xlabel('Time [s]'),ylabel('Speed [rpm]'),grid,hold on 
    legend('low','medium','high',4)
   figure('Units','Normalized','Position',[.02 .1 .5 .35],'Name','Induction motor starting transients');
  figure(2)
   plot(t,Te,co(k));title(s1,'color','m','fontweight','bold');xlabel('Time [s]'),ylabel('Torque [N.m]'),grid,hold on
   legend('low','medium','high',1)
   figure('Units','Normalized','Position',[.53 .1 .45 .35],'Name','Induction motor starting transients'); 
  figure(3)
   plot(t,is,co(k));title(s1,'color','y','fontweight','bold');xlabel('Time [s]]'),ylabel('Current [A]'),grid,hold on
   legend('low','medium','high',1)
  end 
%%% 
   h0=figure('Units','Normalized','menubar','none','numbertitle','off','Position',[.7 .7 .1 .15]); 
 
      uicontrol('Parent',h0, ...
          'Units','normalized', ...
	      'BackgroundColor',[0.5 0.5 0.5], ...
	      'Callback','clc,clear,close all,return', ...
	      'FontSize',10, ...
	      'FontWeight','bold', ...
          'ForegroundColor',[1 1 1], ...
 	      'Position',[0.27 0.06 0.55 0.2], ...
	      'String','CLOSE', ...
	      'TooltipString','Close'); 
       uicontrol('Parent',h0, ...
          'Units','normalized', ...
	      'BackgroundColor',[0.5 0.5 0.5], ...
	      'Callback','edit imstartrotoreffect', ...
	      'FontSize',10, ...
	      'FontWeight','bold', ...
          'ForegroundColor',[1 1 1], ...
 	      'Position',[0.27 0.39 0.55 0.2], ...
	      'String','EDIT', ...
	      'TooltipString','Edit');
      uicontrol('Parent',h0, ...
          'Units','normalized', ...
	      'BackgroundColor',[0.5 0.5 0.5], ...
	      'Callback','run imstartrotoreffect', ...
	      'FontSize',10, ...
	      'FontWeight','bold', ...
          'ForegroundColor',[1 1 1], ...
 	      'Position',[0.27 0.7 0.55 0.2], ...
	      'String','RUN', ...
	      'TooltipString','Run');

   close Figure 4
   close Figure 5
   close Figure 6
   close Figure 7
   close Figure 8
   close Figure 9
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function dxdt=IMstf(t,x)
global L p Rr J
% --------------------     MACHINE PARAMETERS -----------------------------
Vll=220    ; %Line-to-line rms voltage rating [V]
Rs=0.531    ; %Stator resistance (Ohm)
%Rr=0.408   ; %Rotor resistance  (Ohm)
Lsl=2.5e-3 ; %Stator leakage inductance(H)
Lrl=2.5e-3    ; %Rotor leakage inductance  (H)
Lm=84.7e-3   ; %Magnetizing inductance  (H) 
freq0=60   ; %Base frequency (Hz)
wo=2*pi*freq0 ; %Base frequency (rad/s)
p=4        ; %number of poles
%J=0.1    ; %Moment of inertia (kg.m^2)
TLf=15; %Load torque [N.m]
Bm=0.02; %Damping constant
% -------------------------INDUCTANCE MATRIX-------------------------------
Ls=Lsl+Lm ; Lr=Lrl+Lm;

L=[Ls  0   Lm  0   
   0   Ls  0   Lm 
   Lm  0   Lr  0
   0   Lm  0   Lr];
  
% --------------------------STATE EQUATIONS-------------------------------- 
 wm=x(5) ; 
 wk=wo;
         if t<1.4, TL=0;else TL=TLf; end
 Vs=Vll*sqrt(2/3);
 psi=x(6);
 vas=Vs*cos(wo*t);    vbs=Vs*sin(wo*t);
 
 vabs=[vas;vbs];
      Rotf=[cos(psi)  sin(psi)
          -sin(psi)  cos(psi) ];
 vdqs=Rotf*vabs;
 vds=vdqs(1); vqs=vdqs(2);
 
    V=[vds vqs 0 0]';
    F=[x(1) x(2) x(3) x(4)]';
    I=L\F;
     
   R=diag([Rs Rs Rr Rr]);
    
   W=[ 0        -wk         0        0
      wk         0          0        0
       0         0          0     -(wk-wm)
       0         0       (wk-wm)     0     ];
   
  Te=(3/2)*(p/2)*(I(2)*F(1)-I(1)*F(2));  
 %%% Matrix formulation of induction machine equations in common reference frame   
 %%% V= R*I + W*F + dF/dt   where I = Linv*F
   
dfdt=V-R*I-W*F;
%dfdt=V-(L\R+W)*F;
dwmdt=p/2*(Te-TL)/J-Bm/J*wm;
dxdt  =[dfdt;dwmdt;wk]; % State equations
% -------------------------------------------------------------------------
