%   TRAVELING WAVES in SQUIRREL-CAGE INDUCTION MOTOR in ROTOR FRAME
clc,clear,close all
disp(date)
info= ...
        ['       Squirrel-cage rotor in a 2-pole field         '                                
         ' This demo animates the motion of a flux-density wave'  
         ' traveling past a squirrel-cage rotor at slip speed. '
         ' It also shows the instantaneous bar voltages and    '
         ' and currents with the corresponding rotor mmf wave. '
         ' A movie can also be run under Windows Media Player  '
         ' by activating "squirrelcage.avi" file just created. '
         ' You select the number of rotor bars.                '
         ' ----------------------------------------------------'];     
disp(info) 

disp('   Enter number of rotor bars:')
nbar=input('nbar  (default = 20) = ');
    if isempty(nbar)==1, nbar=20; end; 
w=avifile('squirrelcage.avi','compression','none');
n=198;dphi=2*pi/n;alpha=pi/8;d=8.5;phi=0;

%
  figure('units','normalized','Position',[.15 .09 .805 .7],'Name','SQUIRREL-CAGE ROTOR IN A 2-POLE FIELD',...
        'NumberTitle','off');
 set(gcf,'color',[1 1 1])          
 for k=1:n
       theta=0:2*pi/nbar:2*pi; 
      q=nbar/(length(theta)-1)*(0:length(theta)-1);
      fA=-1.4*(cos(phi)*sin(theta)-sin(phi)*cos(theta));
      fB=-(cos(phi-alpha)*sin(theta)-sin(phi-alpha)*cos(theta));
      fD=-2.2*(cos(phi-alpha-pi/2)*sin(theta)-sin(phi-alpha-pi/2)*cos(theta));
       thetf=0:pi/30:2*pi;
      q1=nbar/(length(thetf)-1)*(0:length(thetf)-1);
      fC=-1.8*(cos(phi)*sin(thetf)-sin(phi)*cos(thetf));
      fE=-2.2*(cos(phi-alpha-pi/2)*sin(thetf)-sin(phi-alpha-pi/2)*cos(thetf));
           %
      fill([0 nbar nbar 0 0],[-2.8 -2.8 2.8 2.8 -2.8],[.92 .95 1],'linewidth',2),hold on
       set(gca,'Xlim',[0 nbar],'Ylim',[-2.8 2.8],'visible','off')
        
     for c=1:nbar+1
        plot(c-.5,-0.19,'o','linewidth',2,'MarkerSize',26,'MarkerEdgeColor','k','MarkerFacecolor','y')
        dd=abs(fB(c))*20; 
        if dd==0; dd=.002; end
         plot(c-.5,-0.19,'o','linewidth',2,'MarkerSize',dd,'MarkerEdgeColor','k','MarkerFacecolor','r')
        if fB(c)<0
          plot(c-.5,-.19,'k.','MarkerSize',dd*2,'LineWidth',4)
          else    
          plot(c-.5,-.19,'kx','MarkerSize',dd*.8,'LineWidth',3)
        end  
     end
        
      text(.4*nbar,-2.25,'\omega_s_l_i_p','fontweight','b','color','k','fontsize',12)
        vecarrow([.35*nbar -2.4],[nbar/2 -2.4],'k')
      plot([0 nbar],[0 0],'-k','Linewidth',2)
      plot(q1,fC,'-g','LineWidth',3)
      plot([0 .5],[fE(59) fE(1)],'-m',q1+.5,fE,'-m','LineWidth',3)
      stairs(q-0.05,fD,'-m')
      stem(q-.5,fA,'b')
      stem(q-.53,fB,'r')
      
      text(nbar/18,-2.4,'Flux density wave','fontweight','b','color','g','fontsize',12)
      text(nbar/18,-2.6,'Rotor mmf wave','fontweight','b','color','m','fontsize',12)
      text(nbar/3,-2.6,'Instantaneous bar voltages','fontweight','b','color','b','fontsize',12)
      text(.7*nbar,-2.6,'Instantaneous bar currents','fontweight','b','color','r','fontsize',12)
      text(nbar/2,2.63,'SQUIRREL-CAGE ROTOR','FontSize',16,'HOR','center','FontWeight','bold','color','blue') 
       
        hold off
      f=getframe(gca);
      w=addframe(w,f);
      phi=phi+dphi;
      M(k)=getframe;
  end
  w=close(w);
  
  uicontrol('Units','normalized', ...
   'Style','PushButton',...
	'BackgroundColor',[.2 .3 .8], ...
	'Callback','movie(M,1)', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[1 1 1], ...
	'Position',[0.24 0.015 0.09 .05], ...
	'String','Repeat', ...
    'TooltipString','Repeat');
    uicontrol('Units','normalized', ...
   'Style','PushButton',...
	'BackgroundColor',[.2 .3 .8], ...
	'Callback','close,clear,close all', ...
	'FontSize',10, ...
	'FontWeight','bold', ...
	'ForegroundColor',[1 1 1], ...
	'Position',[0.63 0.015 0.09 .05], ...
	'String','Quit', ...
    'TooltipString','Quit');
     %     
