% Parametric phasor diagrams of synchronous motor as a function of P
clear,close all
%DATA
V=1.0;
X=1;
E=1.5;
Pmax=E*V/X;
%
q=0;
Ed=[]; Eq=[]; Id=[]; Iq=[];Imag=[];Pmag=[];dmag=[];

avimov=avifile('syncmotB1.avi','compression','none');
     
for P=0:.01:Pmax
    q=q+1;
d=asin(P*X/(E*V));

Ed1=E*cos(d); Eq1=-E*sin(d);
Ebar=Ed1+1i*Eq1;
Vd1=V; Vq1=0;
Vbar=V;
Ibar=(Vbar-Ebar)/(1i*X);
Id1=real(Ibar); Iq1=imag(Ibar);
Imag1=abs(Ibar);
 Ed=[Ed Ed1]; Eq=[Eq Eq1]; Id=[Id Id1]; Iq=[Iq Iq1]; dmag=[dmag d];Pmag=[Pmag P];
end

for k=1:q
    figure('Units','normalized','Position',[0.05 0.17 .9 .55],'Name',' SYNCHRONOUS MOTOR','NumberTitle','on') 
 subplot(1,2,1) 
 
vecarrow([0 0],[V 0],'k'),
 xlabel('Real axis','color',[.2 .6 .2],'Fontweight','b','fontsize',12),
 ylabel('Imaginary axis','color',[.2 .6 .2],'Fontweight','b','fontsize',12) ,hold on
vecarrow([0 0],[Ed(k) Eq(k)],'b')
vecarrow([Ed(k) Eq(k)],[V 0],'g')
vecarrow([0 0],[Id(k) Iq(k)],'r')
set(gca,'Xlim',[0 2],'Ylim',[-1.6 0.6]) 
axis('equal')
h=findobj(gca,'Type','line');
set(h,'LineWidth',2)
plot(Ed,Eq,'b--',Id,Iq,'r--')

for w=1:q
plot(Ed(w),Eq(w),'k')
plot(Id(w),Iq(w),'k')
end

plot(0,0,'kx','MarkerSize',10)
title('Phasor diagrams','fontsize',12,'Fontweight','b','color','r'),
hr=h(length(h):-1:1);
 legend(hr,'V','E','jXI','I')
 plot(0,0,'kx','MarkerSize',10,'linewidth',2)
 a=axis;
 text(.65*a(2),.85*a(3),'V=1  E=1.5  X=1','color',[.2 .2 .1],'fontsize',12,'Fontweight','b')
 text(.65*a(2),.95*a(3),'P = 0:0.01:P_m_a_x','fontsize',12,'Fontweight','b')
 %%%%
 subplot(1,2,2)
 plot(dmag*180/pi,Pmag,'-b'),title('SYNCHRONOUS MOTOR','fontsize',14),
 xlabel('Torque angle \delta','color','b','Fontweight','b','fontsize',12),
 ylabel('Power P','color','r','Fontweight','b','fontsize',12) ,grid,hold on
 plot(dmag(k)*180/pi,Pmag(k),'ro','MarkerSize',5,'MarkerEdgeColor','r','MarkerFacecolor','r')
 h=findobj(gca,'Type','line');
 set(h,'LineWidth',2)
 b=axis;
 text(0.83*b(2),.05*b(4),'E=1.5','color',[.2 .2 .1],'fontsize',12,'Fontweight','b')
 axis([0 100 0 1.6])
 %%%%%
   f=getframe(gcf);
    avimov=addframe(avimov,f);
    % M(k)=getframe;
 end  
  avimov=close(avimov);
